@@ -17,7 +17,8 @@ class FilterOnlyNew(object):
         # Raises an error if plugin isn't available
         plugin.get_plugin_by_name('remember_rejected')
 
-    def on_task_exit(self, task, config):
+    @plugin.priority(-255)
+    def on_task_output(self, task, config):
         """Reject all entries so remember_rejected will reject them next time"""
         if not config or not task.entries:
             return
